==> kubernetes-model-autoscaling-4.12.0-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/MetricSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class MetricSpecBuilder extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecBuilder> implements VisitableBuilder<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecBuilder> {

    io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecFluent<?> fluent;
    Boolean validationEnabled;

    public MetricSpecBuilder() { 
        this(true);
    }


    public MetricSpecBuilder(Boolean validationEnabled) { 
        this(new MetricSpec(), validationEnabled);
    }


    public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecFluent<?> fluent) { 
        this(fluent, true);
    }


    public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new MetricSpec(), validationEnabled);
    }


    public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec instance) { 
        this(fluent, instance, true);
    }


    public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withExternal(instance.getExternal()); 
        fluent.withObject(instance.getObject()); 
        fluent.withPods(instance.getPods()); 
        fluent.withResource(instance.getResource()); 
        fluent.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }


    public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec instance) { 
        this(instance,true);
    }


    public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withExternal(instance.getExternal()); 
        this.withObject(instance.getObject()); 
        this.withPods(instance.getPods()); 
        this.withResource(instance.getResource()); 
        this.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }


    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec build() {
        MetricSpec buildable = new MetricSpec(fluent.getExternal(),fluent.getObject(),fluent.getPods(),fluent.getResource(),fluent.getType());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        MetricSpecBuilder that = (MetricSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-autoscaling-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/MetricSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class MetricSpecBuilder extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecBuilder> {

    io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecFluent<?> fluent;
    Boolean validationEnabled;

    public MetricSpecBuilder() {
        this(true);
    }

    public MetricSpecBuilder(Boolean validationEnabled) {
        this(new MetricSpec(), validationEnabled);
    }

    public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new MetricSpec(), validationEnabled);
    }

    public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec instance) {
        this(fluent, instance, true);
    }

    public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withContainerResource(instance.getContainerResource()); 
        fluent.withExternal(instance.getExternal()); 
        fluent.withObject(instance.getObject()); 
        fluent.withPods(instance.getPods()); 
        fluent.withResource(instance.getResource()); 
        fluent.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }

    public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec instance) {
        this(instance,true);
    }

    public MetricSpecBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withContainerResource(instance.getContainerResource()); 
        this.withExternal(instance.getExternal()); 
        this.withObject(instance.getObject()); 
        this.withPods(instance.getPods()); 
        this.withResource(instance.getResource()); 
        this.withType(instance.getType()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.MetricSpec build() {
        MetricSpec buildable = new MetricSpec(fluent.getContainerResource(),fluent.getExternal(),fluent.getObject(),fluent.getPods(),fluent.getResource(),fluent.getType());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        MetricSpecBuilder that = (MetricSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
